==> galileo-1.26.0.tar.gz: galileo-1.26.0/src/galileo/resources/api/data/manual_llm_validate_scorers_llm_validate_post.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.generated_scorer_validation_response import GeneratedScorerValidationResponse
from ...models.http_validation_error import HTTPValidationError
from ...models.manual_llm_validate_scorers_llm_validate_post_body import ManualLlmValidateScorersLlmValidatePostBody
from ...types import Response


def _get_kwargs(*, body: ManualLlmValidateScorersLlmValidatePostBody) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.POST,
        "return_raw_response": True,
        "path": "/scorers/llm/validate",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    if response.status_code == 200:
        return GeneratedScorerValidationResponse.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Optional[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[GeneratedScorerValidationResponse, HTTPValidationError]
    """

    return sync_detailed(client=client, body=body).parsed


async def asyncio_detailed(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Optional[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[GeneratedScorerValidationResponse, HTTPValidationError]
    """

    return (await asyncio_detailed(client=client, body=body)).parsed

==> galileo-1.29.1.tar.gz: galileo-1.29.1/src/galileo/resources/api/data/manual_llm_validate_scorers_llm_validate_post.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.generated_scorer_validation_response import GeneratedScorerValidationResponse
from ...models.http_validation_error import HTTPValidationError
from ...models.manual_llm_validate_scorers_llm_validate_post_body import ManualLlmValidateScorersLlmValidatePostBody
from ...types import Response


def _get_kwargs(*, body: ManualLlmValidateScorersLlmValidatePostBody) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.POST,
        "return_raw_response": True,
        "path": "/scorers/llm/validate",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    if response.status_code == 200:
        return GeneratedScorerValidationResponse.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate.

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]
    """
    kwargs = _get_kwargs(body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Optional[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate.

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[GeneratedScorerValidationResponse, HTTPValidationError]
    """
    return sync_detailed(client=client, body=body).parsed


async def asyncio_detailed(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate.

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[GeneratedScorerValidationResponse, HTTPValidationError]]
    """
    kwargs = _get_kwargs(body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *, client: ApiClient, body: ManualLlmValidateScorersLlmValidatePostBody
) -> Optional[Union[GeneratedScorerValidationResponse, HTTPValidationError]]:
    """Manual Llm Validate.

    Args:
        body (ManualLlmValidateScorersLlmValidatePostBody):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[GeneratedScorerValidationResponse, HTTPValidationError]
    """
    return (await asyncio_detailed(client=client, body=body)).parsed
